/**
 * sigma_view_yaml_block.js
 * 
 * Creates Slack Block Kit blocks for displaying Sigma rule YAML content
 * 
 */
const logger = require('../../utils/logger');

const { getFileName } = require('../../utils/file_utils');
const FILE_NAME = getFileName(__filename);

/**
 * Create Slack block kit blocks for displaying YAML content
 * 
 * @param {string} ruleId - The ID of the rule
 * @param {string} yamlContent - The YAML content to display
 * @returns {Array} Formatted Slack blocks ready for display
 */
function getYamlViewBlocks(ruleId, yamlContent) {
  logger.debug(`${FILE_NAME}: Creating YAML view blocks for rule: ${ruleId || 'unknown'}`);
  
  if (!yamlContent) {
    logger.warn(`${FILE_NAME}: Empty YAML content for rule: ${ruleId}`);
    return [
      {
        type: 'header',
        text: {
          type: 'plain_text',
          text: `YAML for Rule: ${ruleId}`,
          emoji: true
        }
      },
      {
        type: 'section',
        text: {
          type: 'mrkdwn',
          text: '_No YAML content available_'
        }
      }
    ];
  }

  const blocks = [
    {
      type: 'header',
      text: {
        type: 'plain_text',
        text: `YAML for Rule: ${ruleId}`,
        emoji: true
      }
    },
    {
      type: 'section',
      text: {
        type: 'mrkdwn',
        text: '```\n' + yamlContent + '```'
      }
    }
  ];

  blocks.push({
    type: 'actions',
    elements: [
      {
        type: 'button',
        text: {
          type: 'plain_text',
          text: 'Convert to SIEM Rule',
          emoji: true
        },
        action_id: 'convert_rule_to_siem',
        value: `convert_rule_to_siem_${ruleId}`
      },
    ]
  });

  logger.debug(`${FILE_NAME}: Created ${blocks.length} blocks for YAML view`);
  return blocks;
}

module.exports = {
  getYamlViewBlocks
};