/**
 * formatters/index.js
 *
 * Exports all formatters for easy importing
 */

// Text and table formatters
const textFormatter = require('./text_formatter');
const tableFormatter = require('./table_formatter');

// Domain-specific formatters
const sigmaFormatter = require('./sigma_formatter');

// Re-export all formatters
module.exports = {
  // Text utilities
  wrapText: textFormatter.wrapText,
  formatDate: textFormatter.formatDate,
  formatNumber: textFormatter.formatNumber,
  
  // Table utilities
  formatTable: tableFormatter.formatTable,
  formatKeyValueTable: tableFormatter.formatKeyValueTable,
  formatTableHeader: tableFormatter.formatTableHeader,
  formatTableRow: tableFormatter.formatTableRow,
  
  // Sigma formatters
  formatSigmaDetails: sigmaFormatter.formatSigmaDetails,
  formatSigmaStats: sigmaFormatter.formatSigmaStats,
  formatSigmaSearchResults: sigmaFormatter.formatSigmaSearchResults,
  
  // Rendering functions for CLI output
  renderSigmaDetails: sigmaFormatter.renderSigmaDetails,
  renderSigmaStats: sigmaFormatter.renderSigmaStats,
  renderSigmaSearchResults: sigmaFormatter.renderSigmaSearchResults
};