/**
 * colors.js
 * 
 * Centralized color definitions and formatting functions for CLI output
 * Using direct ANSI color codes instead of chalk
 */

// Define ANSI color codes
const ansiCodes = {
    // Text formatting
    reset: '\x1b[0m',
    bold: '\x1b[1m',
    dim: '\x1b[2m',
    underscore: '\x1b[4m',
    blink: '\x1b[5m',
    reverse: '\x1b[7m',
    hidden: '\x1b[8m',
  
    // Foreground colors
    black: '\x1b[30m',
    red: '\x1b[31m',
    green: '\x1b[32m',
    yellow: '\x1b[33m',
    blue: '\x1b[34m',
    magenta: '\x1b[35m',
    cyan: '\x1b[36m',
    white: '\x1b[37m',
  
    // Background colors
    bgBlack: '\x1b[40m',
    bgRed: '\x1b[41m',
    bgGreen: '\x1b[42m',
    bgYellow: '\x1b[43m',
    bgBlue: '\x1b[44m',
    bgMagenta: '\x1b[45m',
    bgCyan: '\x1b[46m',
    bgWhite: '\x1b[47m'
  };
  
  // Create color formatting functions
  const colors = {
    // Basic formatting functions
    blue: (text) => `${ansiCodes.blue}${text}${ansiCodes.reset}`,
    green: (text) => `${ansiCodes.green}${text}${ansiCodes.reset}`,
    red: (text) => `${ansiCodes.red}${text}${ansiCodes.reset}`,
    yellow: (text) => `${ansiCodes.yellow}${text}${ansiCodes.reset}`,
    cyan: (text) => `${ansiCodes.cyan}${text}${ansiCodes.reset}`,
    white: (text) => `${ansiCodes.white}${text}${ansiCodes.reset}`,
    dim: (text) => `${ansiCodes.dim}${text}${ansiCodes.reset}`,
    bold: (text) => `${ansiCodes.bold}${text}${ansiCodes.reset}`,
    
    // Composite styles for specific UI elements
    header: (text) => `${ansiCodes.cyan}${ansiCodes.bold}${text}${ansiCodes.reset}`,
    key: (text) => `${ansiCodes.blue}${text}${ansiCodes.reset}`,
    statsKey: (text) => `${ansiCodes.yellow}${text}${ansiCodes.reset}`,
    value: (text) => `${ansiCodes.white}${text}${ansiCodes.reset}`,
    count: (text) => `${ansiCodes.green}${text}${ansiCodes.reset}`,
    error: (text) => `${ansiCodes.red}${text}${ansiCodes.reset}`,
    warning: (text) => `${ansiCodes.yellow}${text}${ansiCodes.reset}`,
    success: (text) => `${ansiCodes.green}${ansiCodes.bold}${text}${ansiCodes.reset}`
  };
  
  module.exports = colors;