/**
 * index.js
 * Central module for accessing all Sigma database query functions
 */

// Import functions from individual modules
const ruleRetrieval = require('./rule-retrieval');
const simpleSearch = require('./simple-search');
const ftsSearch = require('./fts-search');
const complexSearch = require('./complex-search');
const statsDebug = require('./stats-debug');

// Export all functions
module.exports = {
  // Rule retrieval functions
  getAllRuleIds: ruleRetrieval.getAllRuleIds,
  findRuleById: ruleRetrieval.findRuleById,
  
  // Search functions
  searchRules: simpleSearch.searchRules,
  
  // FTS search functions
  searchRulesFTS: ftsSearch.searchRulesFTS,
  checkFtsAvailable: ftsSearch.checkFtsAvailable,
  
  // Complex search functions
  searchRulesComplex: complexSearch.searchRulesComplex,
  searchRulesComplexFTS: complexSearch.searchRulesComplexFTS,
  
  // Stats and debug functions
  debugRuleContent: statsDebug.debugRuleContent,
  getRuleYamlContent: statsDebug.getRuleYamlContent,
  getStatsFromDatabase: statsDebug.getStatsFromDatabase
};